@@ -1,7 +1,7 @@
 
 import os
 import typeguard
-from time import strftime, gmtime
+from time import strftime
 from ast import literal_eval  # str to dict
 import boto3  # regions
 from cloud_governance.common.logger.logger_time_stamp import logger_time_stamp, logger
@@ -154,6 +154,7 @@ def main():
     # environment variables - get while running the docker
     region_env = os.environ.get('AWS_DEFAULT_REGION', 'us-east-2')
     dry_run = os.environ.get('dry_run', 'yes')
+
     account = os.environ.get('account', '')
     policy = os.environ.get('policy', '')
     upload_data_es = os.environ.get('upload_data_es', '')
